@@ -7,11 +7,11 @@ from math import ceil as _ceil, sqrt as _sqrt
 
 from sympy.core.compatibility import SYMPY_INTS, range
 from sympy.core.mul import prod
-from sympy.polys.polyutils import _sort_factors
+from sympy.ntheory import factorint
 from sympy.polys.polyconfig import query
 from sympy.polys.polyerrors import ExactQuotientFailed
+from sympy.polys.polyutils import _sort_factors
 
-from sympy.ntheory import factorint
 
 def gf_crt(U, M, K=None):
     """
@@ -21,7 +21,10 @@ def gf_crt(U, M, K=None):
     co-prime integer moduli ``m_0,...,m_n``, returns an integer
     ``u``, such that ``u = u_i mod m_i`` for ``i = ``0,...,n``.
 
-    As an example consider a set of residues ``U = [49, 76, 65]``
+    Examples
+    ========
+
+    Consider a set of residues ``U = [49, 76, 65]``
     and a set of moduli ``M = [99, 97, 95]``. Then we have::
 
        >>> from sympy.polys.domains import ZZ
@@ -682,8 +685,8 @@ def gf_div(f, g, p, K):
     References
     ==========
 
-    1. [Monagan93]_
-    2. [Gathen99]_
+    .. [1] [Monagan93]_
+    .. [2] [Gathen99]_
 
     """
     df = gf_degree(f)
@@ -978,7 +981,7 @@ def gf_pow_mod(f, n, g, p, K):
     References
     ==========
 
-    1. [Gathen99]_
+    .. [1] [Gathen99]_
 
     """
     if not n:
@@ -1103,7 +1106,7 @@ def gf_gcdex(f, g, p, K):
     References
     ==========
 
-    1. [Gathen99]_
+    .. [1] [Gathen99]_
 
     """
     if not (f or g):
@@ -1319,7 +1322,7 @@ def gf_trace_map(a, b, c, n, f, p, K):
     References
     ==========
 
-    1. [Gathen92]_
+    .. [1] [Gathen92]_
 
     """
     u = gf_compose_mod(a, b, f, p, K)
@@ -1465,7 +1468,7 @@ def gf_irred_p_rabin(f, p, K):
 
     x = [K.one, K.zero]
 
-    indices = set([ n//d for d in factorint(n) ])
+    indices = { n//d for d in factorint(n) }
 
     b = gf_frobenius_monomial_base(f, p, K)
     h = b[1]
@@ -1601,7 +1604,7 @@ def gf_sqf_list(f, p, K, all=False):
     References
     ==========
 
-    1. [Geddes92]_
+    .. [1] [Geddes92]_
 
     """
     n, sqf, factors, r = 1, False, [], int(p)
@@ -1827,8 +1830,8 @@ def gf_ddf_zassenhaus(f, p, K):
     References
     ==========
 
-    1. [Gathen99]_
-    2. [Geddes92]_
+    .. [1] [Gathen99]_
+    .. [2] [Geddes92]_
 
     """
     i, g, factors = 1, [K.one, K.zero], []
@@ -1874,11 +1877,11 @@ def gf_edf_zassenhaus(f, n, p, K):
     References
     ==========
 
-    1. [Gathen99]_
-    2. [Geddes92]_
+    .. [1] [Gathen99]_
+    .. [2] [Geddes92]_
 
     """
-    factors, q = [f], int(p)
+    factors = [f]
 
     if gf_degree(f) <= n:
         return factors
@@ -1936,9 +1939,9 @@ def gf_ddf_shoup(f, p, K):
     References
     ==========
 
-    1. [Kaltofen98]_
-    2. [Shoup95]_
-    3. [Gathen92]_
+    .. [1] [Kaltofen98]_
+    .. [2] [Shoup95]_
+    .. [3] [Gathen92]_
 
     """
     n = gf_degree(f)
@@ -2009,8 +2012,8 @@ def gf_edf_shoup(f, n, p, K):
     References
     ==========
 
-    1. [Shoup91]_
-    2. [Gathen92]_
+    .. [1] [Shoup91]_
+    .. [2] [Gathen92]_
 
     """
     N, q = gf_degree(f), int(p)
@@ -2174,7 +2177,7 @@ def gf_factor(f, p, K):
     References
     ==========
 
-    1. [Gathen99]_
+    .. [1] [Gathen99]_
 
     """
     lc, f = gf_monic(f, p, K)
@@ -2228,8 +2231,10 @@ def linear_congruence(a, b, m):
 
     There are 3 solutions distinct mod(15) since gcd(a, m) = gcd(3, 15) = 3.
 
-    **Reference**
-    1) Wikipedia http://en.wikipedia.org/wiki/Linear_congruence_theorem
+    References
+    ==========
+
+    .. [1] https://en.wikipedia.org/wiki/Linear_congruence_theorem
 
     """
     from sympy.polys.polytools import gcdex
@@ -2338,8 +2343,8 @@ def gf_csolve(f, n):
     References
     ==========
 
-    [1] 'An introduction to the Theory of Numbers' 5th Edition by Ivan Niven,
-        Zuckerman and Montgomery.
+    .. [1] 'An introduction to the Theory of Numbers' 5th Edition by Ivan Niven,
+           Zuckerman and Montgomery.
 
     """
     from sympy.polys.domains import ZZ
